pub struct DeviceCodePhaseOneResponse<'a> { /* private fields */ }Expand description
Contains the required information to allow a user to sign in.
Implementations
Sourceimpl DeviceCodePhaseOneResponse<'_>
impl DeviceCodePhaseOneResponse<'_>
Sourcepub fn stream(
&self,
) -> Pin<Box<impl Stream<Item = Result<DeviceCodeAuthorization>> + '_>>
pub fn stream( &self, ) -> Pin<Box<impl Stream<Item = Result<DeviceCodeAuthorization>> + '_>>
Polls the token endpoint while the user signs in.
This will continue until either success or a terminal error is
returned. Per RFC 8628 3.5 the authorization_pending and
slow_down server errors keep the poll loop alive; slow_down
additionally requires the client to extend its polling interval by
5 seconds.